#
# spec file for package orthanc-python
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2020-2024 Dr. Axel Braun
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           orthanc-python
Version:        4.3
Release:        1.4
Summary:        Python plugin for Orthanc
License:        AGPL-3.0-or-later
Group:          Productivity/Graphics/Viewers
URL:            https://orthanc-server.com
Source0:        https://orthanc.uclouvain.be/downloads/sources/%{name}/OrthancPython-%{version}.tar.gz
Source11:       orthanc-python-readme.openSUSE
BuildRequires:  cmake
%if 0%{?suse_version} == 1500 && 0%{?sle_version} > 150200
BuildRequires:  gcc13-c++
%else
BuildRequires:  gcc-c++
%endif
BuildRequires:  jsoncpp-devel
BuildRequires:  libboost_atomic-devel >= 1.66
BuildRequires:  libboost_date_time-devel >= 1.66
BuildRequires:  libboost_filesystem-devel >= 1.66
BuildRequires:  libboost_iostreams-devel >= 1.66
BuildRequires:  libboost_locale-devel >= 1.66
BuildRequires:  libboost_regex-devel >= 1.66
BuildRequires:  libboost_system-devel >= 1.66
BuildRequires:  libboost_thread-devel >= 1.66
BuildRequires:  libuuid-devel
BuildRequires:  orthanc-devel >= 1.10
BuildRequires:  orthanc-source
BuildRequires:  pkgconfig
BuildRequires:  python3-devel
BuildRequires:  unzip
BuildRequires:  pkgconfig(python3)
Requires:       orthanc

%description
This plugin can be used to write Orthanc plugins in Python instead of C++
See %{_docdir}/orthanc/orthanc-python-readme.openSUSE

%prep
%autosetup -n OrthancPython-%{version}

echo %{python3_version}

%build
%if 0%{?suse_version} == 1500 && 0%{?sle_version} > 150200
export CC=gcc-13
export CXX=g++-13
%endif
%cmake .. \
       -DALLOW_DOWNLOADS=OFF \
       -DUSE_SYSTEM_GOOGLE_TEST=ON \
       -DUSE_SYSTEM_ORTHANC_SDK=ON \
       -DORTHANC_FRAMEWORK_SOURCE=path \
       -DBoost_NO_BOOST_CMAKE=ON \
       -DPYTHON_VERSION=%{python3_version} \
       -DORTHANC_FRAMEWORK_ROOT=%{_prefix}/src/orthanc/OrthancFramework/Sources \
       -DLIB_INSTALL_DIR=%{_libdir}/share/orthanc/plugins/

%cmake_build %{?_smp_mflags}

%install
%cmake_install

# architecture dependet files should not be in /usr/share...
# create a directory
mkdir -p -m 755 %{buildroot}%{_libdir}/share/orthanc/plugins
mkdir -p -m 755 %{buildroot}%{_docdir}/orthanc

mv %{buildroot}%{_datadir}/orthanc/plugins/*.so* %{buildroot}%{_libdir}/share/orthanc/plugins/.

#Link from lib64 to orthanc plugin-directory, where it is expected
ln -s ../../../..%{_libdir}/share/orthanc/plugins/libOrthancPython.so.%{version} \
      %{buildroot}%{_datadir}/orthanc/plugins/libOrthancPython.so

rm %{buildroot}%{_libdir}/share/orthanc/plugins/*.so

cp %{SOURCE11} %{buildroot}%{_docdir}/orthanc/.

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%license COPYING
%dir %{_docdir}/orthanc
%{_docdir}/orthanc/*
%dir %{_libdir}/share
%dir %{_libdir}/share/orthanc
%dir %{_libdir}/share/orthanc/plugins
%{_libdir}/share/orthanc/plugins/*.so*
%dir %{_datadir}/orthanc
%dir %{_datadir}/orthanc/plugins
%{_datadir}/orthanc/plugins/*.so*

%changelog
* Mon Jul  8 2024 Axel Braun <axel.braun@gmx.de>
- version 4.3
  * Created Python documentation for the Orthanc interface, check out "orthanc.pyi"
  * Added option "AllowThreads" to release the GIL during the call to the native SDK functions
  * Code model is now generated by the "orthanc-java" project
  * Added Windows builder for Python 3.12
  * Licensing information is now compliant with the FSFE REUSE specification
* Tue May 21 2024 Axel Braun <axel.braun@gmx.de>
- version 4.2
  * Fix signature of "orthanc.RestOutput.SendHttpStatus()"
  * Added orthanc.RegisterMoveCallback2() that takes 4 callbacks like the
    original C SDK function.  This allows you to implement a correct handling
    of the C-Move sub-operations count in the GetMoveSize().  The ApplyMove()
    must now handle a single sub-operation at a time.
    The legacy orthanc.RegisterMoveCallback() always considers that there is a single
    sub-operation and we have observed modalities complaining that the number of
    sub-operations was not matching the number of instances sent.
* Wed Mar 13 2024 Axel Braun <axel.braun@gmx.de>
- enable gcc13 for Leap 15, %%{?sle15_python_module_pythons}
* Wed Sep 20 2023 Axel Braun <axel.braun@gmx.de>
- Version 4.1
  * New function from the SDK wrapped in Python:
  - orthanc.RegisterStorageCommitmentScpCallback()
  * New configuration section "Python" to group settings related to the plugin:
  - "Python.Path" is an alias for global option "PythonScript"
  - "Python.Verbose" is an alias for global option "PythonVerbose"
  * New configuration option "Python.DisplayMemoryUsage" to periodically
    display memory allocations that stem from Python plugins
  * Fix memory leaks when a python script calls orthanc.RestApiPost() and sibling
    methods, in IncomingHttpRequestFilter and in the CMove callback.
  * New builders for Windows: Supporting 32 / 64bit with Python 3.9 / 3.10 / 3.11
* Mon Dec  5 2022 Dirk Müller <dmueller@suse.com>
- update to 4.0:
  * New functions from the SDK wrapped in Python:
  - orthanc.RegisterIncomingCStoreInstanceFilter()
  - orthanc.RegisterReceivedInstanceCallback()
* Wed Sep  1 2021 Axel Braun <axel.braun@gmx.de>
- Version 3.4
  * On Orthanc stopping, wait for all the queued events to have been processed
  * Docker-based builder scripts distinguishing Debian buster and bullseye
* Sat Aug 14 2021 Axel Braun <axel.braun@gmx.de>
- version 3.3
  * New Python function: "orthanc.RegisterStorageArea()"
  * Custom exception "orthanc.OrthancException" is raised instead of "ValueError"
* Sat Jun 19 2021 Axel Braun <axel.braun@gmx.de>
- version 3.2
  * New functions from the SDK wrapped in Python:
  - orthanc.CreateDicom()
  - orthanc.CreateImageFromBuffer()
  - orthanc.DicomInstance.GetInstanceData()
  - orthanc.FindQuery.GetFindQueryTagElement()
  - orthanc.FindQuery.GetFindQueryTagGroup()
  - orthanc.Image.GetImageBuffer()
  - orthanc.LookupDictionary()
  - orthanc.RegisterFindCallback()
  - orthanc.RegisterMoveCallback()
  - orthanc.RegisterWorklistCallback()
  - orthanc.WorklistAnswers.WorklistAddAnswer()
* Mon Jan 25 2021 Axel Braun <axel.braun@gmx.de>
- verion 3.1
  * Fix possible deadlock with "orthanc.RegisterOnChangeCallback()"
  * During Orthanc shutdown, wait for all the pending events to have been processed
* Tue Dec 22 2020 Axel Braun <axel.braun@gmx.de>
- Version 3.0
  initial OBS build
